@@ -7,7 +7,7 @@ class SDK:
         # Si se le indica el procesador
         self._sdk = None
         if processor == 'mercadopago':
-            self.processor = 'mercagopado'
+            self.processor = 'mercadopago'
             self._sdk = MercadoPagoSDK(merchant, marketplace=marketplace)
         elif processor == 'decidir':
             self.processor = 'decidir'
